@@ -1,6 +1,6 @@
 package YellowBot::API;
 BEGIN {
-  $YellowBot::API::VERSION = '0.90';
+  $YellowBot::API::VERSION = '0.91';
 }
 
 use warnings;
@@ -43,7 +43,7 @@ sub _build_ua {
     return $ua;
 }
 
-sub request {
+sub _request {
     my ($self, $method, %args) = @_;
     return YellowBot::API::Request->new(
         method => $method,
@@ -55,10 +55,25 @@ sub request {
 
 sub call {
     my $self = shift;
-    my $http_response = $self->ua->request( $self->request(@_)->http_request );
+    my $http_response = $self->ua->request( $self->_request(@_)->http_request );
     return YellowBot::API::Response->new(http => $http_response)->data;
 }
 
+sub signin_url {
+    my $self   = shift;
+    my %args   = @_;
+    my $domain = $args{domain} ? "http://$args{domain}" : $self->server;
+    my $uri    = URI->new("$domain/signin/partner");
+    $uri->query(
+        YellowBot::API::Request::_query(
+            %args,
+            api_key    => $self->api_key,
+            api_secret => $self->api_secret,
+        )
+    );
+    return $uri->as_string;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 local ($YellowBot::API::VERSION) = ('devel') unless defined $YellowBot::API::VERSION;
@@ -67,6 +82,10 @@ local ($YellowBot::API::VERSION) = ('devel') unless defined $YellowBot::API::VER
 
 __END__
 
+=pod
+
+=encoding utf8
+
 =head1 NAME
 
 YellowBot::API - The great new YellowBot::API!
@@ -94,6 +113,13 @@ YellowBot::API - The great new YellowBot::API!
     }
 
 
+    my $signin_url = $api->signin_url(
+       domain => 'reputation.example.com',
+       api_user_identifier => 'abc123',
+       brand => 'yellowbot',
+    );
+
+
 =head1 METHODS
 
 =head2 call( $endpoint, %args )
@@ -102,12 +128,17 @@ Calls the endpoint (see the YellowBot API documentation) with the
 specified arguments.  Returns a hash data structure with the API
 results.
 
+=head2 signin_url( %options )
+
+Generate a URL for the "silent partner login" feature.  See example
+above and API documentation for details.
 
 =head1 DEBUGGING
 
 If the API_DEBUG environment variable is set to a true value (1 for
 example) the request query and the response will be printed to STDERR.
 
+See also the ybapi utility, L<ybapi>. 
 
 =head1 AUTHOR
 
@@ -115,35 +146,13 @@ Ask Bjørn Hansen, C<< <ask at develooper.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-yellowbot-api at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=YellowBot-API>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to the issue tracker at 
+L<http://github.com/solfo/YellowBot-API-perl/issues>.
 
+The Git repository is available at
+L<http://github.com/solfo/YellowBot-API-perl> (Clone with C<git clone
+http://github.com/solfo/YellowBot-API-perl.git>).
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc YellowBot::API
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=YellowBot-API>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/YellowBot-API>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/YellowBot-API/>
-
-=back
 
 =head1 COPYRIGHT & LICENSE
 
